@@ -8,19 +8,19 @@ class SDK:
         self.processor = None
         if processor == 'mercadopago':
             self._sdk = MercadoPagoSDK(merchant)
-            self.processor == processor
+            self.processor = 'mercadopago'
             return
         elif processor == 'decidir':
             self._sdk = DecidirSDK(merchant)
-            self.processor == processor
+            self.processor = 'decidir'
             return
         # Si no utiliza el preferrred_processor que tenga el merchant
         if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
             self._sdk = DecidirSDK(merchant)
-            self.processor == 'decidir'
+            self.processor = 'decidir'
         else:
             self._sdk = MercadoPagoSDK(merchant)
-            self.processor == 'mercadopago'
+            self.processor = 'mercadopago'
 
     def customer(self):
         return self._sdk.customer()
