@@ -8,9 +8,11 @@ class CardToken:
         self.sdk = sdk
 
     def create(self, card: dict):
-        card_id = card['mercadopago_id'] if 'decidir_id' in card else card['id']
+        if 'mercadopago_id' in card:
+            card['id'] = card['mercadopago_id']
+
         data = {
-            "card_id": card_id
+            "card_id": card['id']
         }
         card_token_response = self.sdk.card_token().create(data)
 
